@@ -321,6 +321,13 @@ class Package(object):
     def _get(self, url, filename, md5_hex=None):
         """ fetches a file and checks for the md5_hex if given
         """
+
+        # since some time in Feb 2009 PyPI uses different and relative URLs
+        # -> complete bullshit
+
+        if url.startswith('../../packages':
+            url = 'http://pypi.python.org/' + url[6:]
+
         try:
             data = urlopen(url).read()
         except urllib2.HTTPError, v:
